Issues
======

If you're opening a support ticket about coveralls not working,
please add ``coveralls debug`` output.

Pull requests
=============

Pull requests with untested code will not be merged straight away.

If you would like to speed up the process, please, write tests.
